<template>
  <div class="container">
    <h1 class="fs-3 fl-4">Service Sign In</h1>
    <p class="fl-5">
      <p>New to KrackNet? <router-link to="/members/signup">Create an account</router-link></p>

      <form class="bg-grey-lighten-3 rounded-2 p-4 my-7 col-md-9 col-lg-7 col-xxl-6">
        <bs-input name="email" v-model="payload.email" label="Email (Account ID)" placeholder="Enter your email address"></bs-input>
        <bs-input name="password" v-model="payload.password" label="Password" type="password" placeholder="Enter your password"></bs-input>
      </form>

      <div class="col-md-9 col-lg-7 col-xxl-6 actions">
        <button class="mr-4 btn btn-primary" type="button" @click="signIn" :disabled="state.$waiting">
          <span v-if="state.$waiting" class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Sign In
        </button>
        <button class="btn btn-secondary" type="button" @click="cancel">Cancel</button>
        <router-link class="ml-5" to="/members/password-reset">Forgot My Password</router-link>
      </div>
    </p>
  </div>
</template>

<script setup>
import BsInput from "/atila-vue/components/bs-input.vue"

const router = useRouter ()
const { state } = useStore ()

const payload = ref ({
  email: '',
  password: '',
})

function cancel () {
  router.back ()
}

onMounted (async () => {
  frontend.log ("firebase ready", "debug")
})

async function signIn () {
  const validators = {email: frontend.validator.email, password: {required: true, len__between: [6, 64]}}
  if (frontend.validator.failed (payload.value, validators)) {
    return
  }
  state.$waiting = true
  const auth = await firebase.getAuth ()
  let userCredential = null
  try {
      userCredential = await firebase.auth.signInWithEmailAndPassword (auth, payload.value.email, payload.value.password)
  } catch (error) {
    return frontend.handle_firebase_error (error, "Sign In")
  }

  const id_token = await auth.currentUser.getIdToken ()
  let resp = await backend.get_access_and_refresh_tokens (
    "ATILA_VUE_AUTH_SIGNIN_WITH_FIREBASE_ID_TOKEN",
    {id_token: id_token}
  )
  if (resp.status_code == 701) return // didn't make request at all

  let errorMessage = ""
  if (resp.error) {
    if (resp.status_code == 403) {
      errorMessage = `Yout account status is ${resp.data.more_info}. Please contact us.`
    } else {
      errorMessage = 'Unknown error occured. Please contact us.'
    }
    return bootstrap.modal ({
      title: "Unable To Sign In",
      text: errorMessage,
      icon: "error",
      closeButtonText: 'Retry'
    })
  }

  if (state.$grp.indexOf ("guest") > -1) {
    bootstrap.toast ({
      title: "Notice", text: "Email verification required. Your access to some advanced features can be restricted.", icon: 'warning',
      buttons: [{text: "Resend Verification Email", class_: "btn-primary", to: '/members/resend-email' }]
    })
  } else {
    bootstrap.toast ({title: "Success", text: "You have successfully signed in."})
  }
  await frontend.initialize_task ()
  frontend.permission.granted  ()
}

onActivated (() => {
  frontend.set_title ()
})
</script>

<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.unauthentification_required ({path: '/'}, {to, from, next})
  }
}
</script>